#!/bin/sh -e

# Copyright (C) 2023, 2024 Centre National de la Recherche Scientifique
# Copyright (C) 2023, 2024 Institut Pierre-Simon Laplace
# Copyright (C) 2023, 2024 Institut de Physique du Globe de Paris
# Copyright (C) 2023, 2024 |Méso|Star> (contact@meso-star.com)
# Copyright (C) 2023, 2024 Observatoire de Paris
# Copyright (C) 2023, 2024 Université de Reims Champagne-Ardenne
# Copyright (C) 2023, 2024 Université de Versaille Saint-Quentin
# Copyright (C) 2023, 2024 Université Paul Sabatier
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

path="$(dirname "${0}")/random01"

gas="${gas}:mesh=${path}/gas_grid.bin"
gas="${gas}:ck=${path}/gas_radiative_properties.bin"
gas="${gas}:temp=${path}/gas_thermodynamic_properties.bin"

ground="${ground}:name=sphere"
ground="${ground}:mesh=${path}/sphere.bin"
ground="${ground}:prop=${path}/surface_properties.bin"
ground="${ground}:brdf=${path}/materials_list.txt"

camera="${camera}:pos=14016200,0,0"
camera="${camera}:tgt=0.0,0.0,0.0"
camera="${camera}:up=0.0,0.0,1.0"
camera="${camera}:fov=60"

image_def="1280x960"
image_spp="16"
image="def=${image_def}:spp=${image_spp}"

spec_min="10000"
spec_max="12000"
spectral="lw=10000,12000"

octree_tau="1"
octree_def="512"
storage="random01_octrees${octree_def}_lw_${spec_min}_${spec_max}_T${octree_tau}.bin"

output="random01_${image_def}x${image_spp}_lw_${spec_min}_${spec_max}.txt"

force_overwrite="-f"
precompute_tetra_normals="-N"
verbose="-v"

export DATA_PATH="${path}"

set -x
htrdr-planets\
 "${force_overwrite}"\
 "${precompute_tetra_normals}"\
 "${verbose}"\
 -G "${ground}"\
 -g "${gas}"\
 -s "${spectral}"\
 -C "${camera}"\
 -i "${image}"\
 -T "${octree_tau}"\
 -V "${octree_def}"\
 -O "${storage}"\
 -o "${output}"
